@@ -117,6 +117,22 @@ class s2py():
         requests.put("https://scratch.mit.edu/site-api/users/curators-in/" +
                      str(sid) + "/invite_curator/?usernames=" + user, headers=self.headers,)
 
+    def postProfileComment(self, user, content, parent_id="", commentee_id=""):
+        self.headers['referer'] = (
+            "https://scratch.mit.edu/users/" + str(user)
+        )
+        data = json.dumps({
+            "commentee_id": commentee_id,
+            "content": content,
+            "parent_id": parent_id,
+        })
+        return requests.post(
+            "https://scratch.mit.edu/site-api/comments/user/"
+            + str(user) + "/add/",
+            headers=self.headers,
+            data=data,
+        )
+    
     def postProjectComment(self, pid, content, parent_id="", commentee_id=""):
         self.headers['referer'] = (
             "https://scratch.mit.edu/projects/" + str(pid)
